@@ -28,16 +28,17 @@ class Pair_Generator(object):
         """Yields all unordered pairs from the list of objects"""
         for i in range(len(self.list_of_objects)-1):
             for j in range(i+1, len(self.list_of_objects)):
-                yield {self.list_of_objects[i], self.list_of_objects[j]}
+                yield (self.list_of_objects[i], self.list_of_objects[j])
     
 
 def main():
     my_list = ['a', 'b', 'c', 'd']
     for pairs in Pair_Generator(my_list).generate_pairs():
-        print pairs
+        print(pairs)
+    print('')
     my_short_list = ['1', '2']
     for pairs in Pair_Generator(my_short_list).generate_pairs():
-        print pairs
+        print(pairs)
 
 
 if __name__ == '__main__':
